%global py2_incdir %(python2 -c 'import distutils.sysconfig; print(distutils.sysconfig.get_python_inc())')
%global py2_libbuilddir %(python2 -c 'import sys; import sysconfig; print("lib.{p}-{v[0]}.{v[1]}".format(p=sysconfig.get_platform(), v=sys.version_info))')

%global srcname pillow

Name:           python2-%{srcname}
Version:        6.2.2
Release:        7%{?dist}
Summary:        Python image processing library

# License: see http://www.pythonware.com/products/pil/license.htm
License:        MIT
URL:            http://python-pillow.github.io/
Source0:        https://github.com/python-pillow/Pillow/archive/%{version}/Pillow-%{version}.tar.gz
# Testdata for CVE backports below
Source1:        CVE_testdata.tar.gz

# Backport fix for CVE-2020-35653
# https://github.com/python-pillow/Pillow/commit/2f409261eb1228e166868f8f0b5da5cda52e55bf
Patch1:         pillow_CVE-2020-35653.patch
# Backport fix for CVE-2020-35654
# https://github.com/python-pillow/Pillow/commit/eb8c1206d6b170d4e798a00db7432e023853da5c
Patch2:         pillow_CVE-2020-35654.patch
# Backport fix for CVE-2020-35655
# https://github.com/python-pillow/Pillow/commit/120eea2e4547a7d1826afdf01563035844f0b7d5
Patch3:         pillow_CVE-2020-35655.patch
# Backport fix for CVE-2021-25289
# https://github.com/python-pillow/Pillow/commit/3fee28eb9479bf7d59e0fa08068f9cc4a6e2f04c
Patch4:         CVE-2021-25289.patch
# Backport fix for CVE-2021-25290
# https://github.com/python-pillow/Pillow/commit/86f02f7c70862a0954bfe8133736d352db978eaa
Patch5:         CVE-2021-25290.patch
# Backport fix for CVE-2021-25291
# https://github.com/python-pillow/Pillow/commit/cbdce6c5d054fccaf4af34b47f212355c64ace7a
Patch6:         CVE-2021-25291.patch
# Backport fix for CVE-2021-25292
# https://github.com/python-pillow/Pillow/commit/3bce145966374dd39ce58a6fc0083f8d1890719c
Patch7:         CVE-2021-25292.patch
# Backport fix for CVE-2021-25293
# https://github.com/python-pillow/Pillow/commit/4853e522bddbec66022c0915b9a56255d0188bf9
Patch8:         CVE-2021-25293.patch
# Backport patch for CVE-2021-2792{1,2,3}
# https://github.com/python-pillow/Pillow/commit/480f6819b592d7f07b9a9a52a7656c10bbe07442.patch
Patch9:         CVE-2021-2792x.patch
# Backport fix for CVE-2021-34552.patch
# https://github.com/python-pillow/Pillow/commit/518ee3722a99d7f7d890db82a20bd81c1c0327fb
# https://github.com/python-pillow/Pillow/commit/5f4504bb03f4edeeef8c2633dc5ba03a4c2a8a97
Patch10:        CVE-2021-34552.patch
# Backport fix for CVE-2021-23437
# https://github.com/python-pillow/Pillow/commit/9e08eb8f78fdfd2f476e1b20b7cf38683754866b
Patch11:        CVE-2021-23437.patch


BuildRequires:  freetype-devel
BuildRequires:  gcc
BuildRequires:  ghostscript
BuildRequires:  lcms2-devel
BuildRequires:  libimagequant-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libraqm-devel
BuildRequires:  libtiff-devel
BuildRequires:  libwebp-devel
BuildRequires:  openjpeg2-devel
BuildRequires:  tk-devel
BuildRequires:  zlib-devel

BuildRequires:  python2-devel
BuildRequires:  python2-numpy
BuildRequires:  python2-olefile
BuildRequires:  python2-setuptools

# For EpsImagePlugin.py
Requires:       ghostscript

Provides:       python2-imaging = %{version}-%{release}
# For MicImagePlugin.py, FpxImagePlugin.py
Requires:       python2-olefile

%global __provides_exclude_from ^%{python2_sitearch}/PIL/.*\\.so$

%description
Python image processing library, fork of the Python Imaging Library (PIL)

This library provides extensive file format support, an efficient
internal representation, and powerful image processing capabilities.

This is a minimal compatibility package for https://pagure.io/fesco/issue/2266


%prep
%autosetup -p1 -a1 -n Pillow-%{version}

cd CVE_testdata
for file in `cat index`; do
    install -Dpm 0644 `basename $file` ../$file;
done


%build
# Build Python 2 modules
%py2_build


%install
# Install Python 2 modules
install -d %{buildroot}/%{py2_incdir}/Imaging
install -m 644 src/libImaging/*.h %{buildroot}/%{py2_incdir}/Imaging
%py2_install

# Drop files which used to be in subpackages which are not provided anymore
rm -rf %{buildroot}%{python2_sitearch}/PIL/_imagingtk*
rm -rf %{buildroot}%{python2_sitearch}/PIL/ImageTk*
rm -rf %{buildroot}%{python2_sitearch}/PIL/SpiderImagePlugin*
rm -rf %{buildroot}%{python2_sitearch}/PIL/ImageQt*

# Drop devel-files
rm -rf %{buildroot}%{py2_incdir}/Imaging/


%check
# Check Python 2 modules
ln -s $PWD/Images $PWD/build/%py2_libbuilddir/Images
cp -R $PWD/Tests $PWD/build/%py2_libbuilddir/Tests
cp -R $PWD/selftest.py $PWD/build/%py2_libbuilddir/selftest.py
pushd build/%py2_libbuilddir
PYTHONPATH=$PWD %{__python2} selftest.py
popd


%files -n python2-%{srcname}
%doc README.rst CHANGES.rst
%license docs/COPYING
%{python2_sitearch}/PIL/
%{python2_sitearch}/Pillow-%{version}-py2.7.egg-info/


%changelog
* Mon Sep 13 2021 Sandro Mani <manisandro@gmail.com> - 6.2.2-7
- Backport fix for CVE-2021-23437

* Sat Jul 24 2021 Sandro Mani <manisandro@gmail.com> - 6.2.2-6
- Backport fix for CVE-2021-34552

* Sat Mar 06 2021 Sandro Mani <manisandro@gmail.com> - 6.2.2-5
- Backport patch for CVE-2021-2792{1,2,3}

* Fri Mar 05 2021 Sandro Mani <manisandro@gmail.com> - 6.2.2-4
- Backport fixes for CVE-2020-35653, CVE-2020-35654, CVE-2020-35655
- Backport fixes for CVE-2021-25289, CVE-2021-25290, CVE-2021-25291, CVE-2021-25292, CVE-2021-25293

* Wed Jul 29 2020 Fedora Release Engineering <releng@fedoraproject.org> - 6.2.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Thu Jan 30 2020 Fedora Release Engineering <releng@fedoraproject.org> - 6.2.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Fri Jan 17 2020 Sandro Mani <manisandro@gmail.com> - 6.2.2-1
- Update to 6.2.2

* Sat Jan 04 2020 Sandro Mani <manisandro@gmail.com> - 6.2.1-2
- Add full description
- %%{python2_sitearch}/* -> %%{python2_sitearch}/PIL/
- Remove files instead of using %%exclude
- Don't provide python-imaging

* Sat Jan 04 2020 Sandro Mani <manisandro@gmail.com> - 6.2.1-1
- Minimal python2-only package
